:py:mod:`piel.file_conversion`
==============================

.. py:module:: piel.file_conversion


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   piel.file_conversion.read_csv_to_pandas
   piel.file_conversion.read_vcd_to_json



.. py:function:: read_csv_to_pandas(file_path: piel.config.piel_path_types)

   This function returns a Pandas dataframe that contains all the simulation data outputted from the simulation run.


.. py:function:: read_vcd_to_json(file_path: piel.config.piel_path_types)
